@@ -1,6 +1,6 @@
 package Crixa;
 {
-  $Crixa::VERSION = '0.02';
+  $Crixa::VERSION = '0.03';
 }
 use Moose;
 use namespace::autoclean;
@@ -9,7 +9,7 @@ use namespace::autoclean;
 
 use Crixa::Channel;
 
-with qw(Crixa::Role::RabbitMQ);
+with qw(Crixa::Engine);
 
 sub connect {
     my $o = shift->new(@_);
@@ -48,8 +48,8 @@ sub channel {
     my $self = shift;
     my $args = @_ == 1 ? $_[0] : {@_};
     return $self->_get_channel($args) unless ref $args;
-    $args->{id}  = $self->_next_channel_id;
-    $args->{_mq} = $self->_mq;
+    $args->{id}     = $self->_next_channel_id;
+    $args->{engine} = $self->engine;
     my $c = Crixa::Channel->new($args);
     $self->_add_channel($c);
     return $c;
@@ -69,7 +69,7 @@ Crixa
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS 
 
