@@ -1,6 +1,6 @@
 package Crixa::Exchange;
 {
-  $Crixa::Exchange::VERSION = '0.02';
+  $Crixa::Exchange::VERSION = '0.03';
 }
 use 5.10.0;
 use Moose;
@@ -8,7 +8,7 @@ use namespace::autoclean;
 
 # ABSTRACT: A Crixa Exchange
 
-with qw(Crixa::Role::RabbitMQ);
+with qw(Crixa::Engine);
 
 has name => ( isa => 'Str', is => 'ro', required => 1 );
 
@@ -53,7 +53,7 @@ Crixa::Exchange
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
